.. arcs.shibboleth.client documentation master file, created by
   sphinx-quickstart on Mon Aug 17 16:32:46 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to arcs.shibboleth.client's documentation!
==================================================

Contents:

.. toctree::
   :maxdepth: 2
   :numbered:

   intro
   shibboleth
   credentials
   forms
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

